Class: Aws::ConnectWisdomService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectWisdomService::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectwisdomservice/client.rb,
sig/client.rbs
Overview
An API client for ConnectWisdomService. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectWisdomService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAssistantAssociationResponseSuccess, _CreateAssistantResponseSuccess, _CreateContentResponseSuccess, _CreateKnowledgeBaseResponseSuccess, _CreateQuickResponseResponseSuccess, _CreateSessionResponseSuccess, _DeleteAssistantAssociationResponseSuccess, _DeleteAssistantResponseSuccess, _DeleteContentResponseSuccess, _DeleteImportJobResponseSuccess, _DeleteKnowledgeBaseResponseSuccess, _DeleteQuickResponseResponseSuccess, _GetAssistantAssociationResponseSuccess, _GetAssistantResponseSuccess, _GetContentResponseSuccess, _GetContentSummaryResponseSuccess, _GetImportJobResponseSuccess, _GetKnowledgeBaseResponseSuccess, _GetQuickResponseResponseSuccess, _GetRecommendationsResponseSuccess, _GetSessionResponseSuccess, _ListAssistantAssociationsResponseSuccess, _ListAssistantsResponseSuccess, _ListContentsResponseSuccess, _ListImportJobsResponseSuccess, _ListKnowledgeBasesResponseSuccess, _ListQuickResponsesResponseSuccess, _ListTagsForResourceResponseSuccess, _NotifyRecommendationsReceivedResponseSuccess, _QueryAssistantResponseSuccess, _RemoveKnowledgeBaseTemplateUriResponseSuccess, _SearchContentResponseSuccess, _SearchQuickResponsesResponseSuccess, _SearchSessionsResponseSuccess, _StartContentUploadResponseSuccess, _StartImportJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateContentResponseSuccess, _UpdateKnowledgeBaseTemplateUriResponseSuccess, _UpdateQuickResponseResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_assistant(params = {}) ⇒ Types::CreateAssistantResponse
Creates an Amazon Connect Wisdom assistant.
-
#create_assistant_association(params = {}) ⇒ Types::CreateAssistantAssociationResponse
Creates an association between an Amazon Connect Wisdom assistant and another resource.
-
#create_content(params = {}) ⇒ Types::CreateContentResponse
Creates Wisdom content.
-
#create_knowledge_base(params = {}) ⇒ Types::CreateKnowledgeBaseResponse
Creates a knowledge base.
-
#create_quick_response(params = {}) ⇒ Types::CreateQuickResponseResponse
Creates a Wisdom quick response.
-
#create_session(params = {}) ⇒ Types::CreateSessionResponse
Creates a session.
-
#delete_assistant(params = {}) ⇒ Struct
Deletes an assistant.
-
#delete_assistant_association(params = {}) ⇒ Struct
Deletes an assistant association.
-
#delete_content(params = {}) ⇒ Struct
Deletes the content.
-
#delete_import_job(params = {}) ⇒ Struct
Deletes the quick response import job.
-
#delete_knowledge_base(params = {}) ⇒ Struct
Deletes the knowledge base.
-
#delete_quick_response(params = {}) ⇒ Struct
Deletes a quick response.
-
#get_assistant(params = {}) ⇒ Types::GetAssistantResponse
Retrieves information about an assistant.
-
#get_assistant_association(params = {}) ⇒ Types::GetAssistantAssociationResponse
Retrieves information about an assistant association.
-
#get_content(params = {}) ⇒ Types::GetContentResponse
Retrieves content, including a pre-signed URL to download the content.
-
#get_content_summary(params = {}) ⇒ Types::GetContentSummaryResponse
Retrieves summary information about the content.
-
#get_import_job(params = {}) ⇒ Types::GetImportJobResponse
Retrieves the started import job.
-
#get_knowledge_base(params = {}) ⇒ Types::GetKnowledgeBaseResponse
Retrieves information about the knowledge base.
-
#get_quick_response(params = {}) ⇒ Types::GetQuickResponseResponse
Retrieves the quick response.
-
#get_recommendations(params = {}) ⇒ Types::GetRecommendationsResponse
Retrieves recommendations for the specified session.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Retrieves information for a specified session.
-
#list_assistant_associations(params = {}) ⇒ Types::ListAssistantAssociationsResponse
Lists information about assistant associations.
-
#list_assistants(params = {}) ⇒ Types::ListAssistantsResponse
Lists information about assistants.
-
#list_contents(params = {}) ⇒ Types::ListContentsResponse
Lists the content.
-
#list_import_jobs(params = {}) ⇒ Types::ListImportJobsResponse
Lists information about import jobs.
-
#list_knowledge_bases(params = {}) ⇒ Types::ListKnowledgeBasesResponse
Lists the knowledge bases.
-
#list_quick_responses(params = {}) ⇒ Types::ListQuickResponsesResponse
Lists information about quick response.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#notify_recommendations_received(params = {}) ⇒ Types::NotifyRecommendationsReceivedResponse
Removes the specified recommendations from the specified assistant's queue of newly available recommendations.
-
#query_assistant(params = {}) ⇒ Types::QueryAssistantResponse
Performs a manual search against the specified assistant.
-
#remove_knowledge_base_template_uri(params = {}) ⇒ Struct
Removes a URI template from a knowledge base.
-
#search_content(params = {}) ⇒ Types::SearchContentResponse
Searches for content in a specified knowledge base.
-
#search_quick_responses(params = {}) ⇒ Types::SearchQuickResponsesResponse
Searches existing Wisdom quick responses in a Wisdom knowledge base.
-
#search_sessions(params = {}) ⇒ Types::SearchSessionsResponse
Searches for sessions.
-
#start_content_upload(params = {}) ⇒ Types::StartContentUploadResponse
Get a URL to upload content to a knowledge base.
-
#start_import_job(params = {}) ⇒ Types::StartImportJobResponse
Start an asynchronous job to import Wisdom resources from an uploaded source file.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_content(params = {}) ⇒ Types::UpdateContentResponse
Updates information about the content.
-
#update_knowledge_base_template_uri(params = {}) ⇒ Types::UpdateKnowledgeBaseTemplateUriResponse
Updates the template URI of a knowledge base.
-
#update_quick_response(params = {}) ⇒ Types::UpdateQuickResponseResponse
Updates an existing Wisdom quick response.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectwisdomservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2934 2935 2936 |
# File 'lib/aws-sdk-connectwisdomservice/client.rb', line 2934 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2937 2938 2939 |
# File 'lib/aws-sdk-connectwisdomservice/client.rb', line 2937 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/aws-sdk-connectwisdomservice/client.rb', line 2907 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectWisdomService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectwisdomservice' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assistant(params = {}) ⇒ Types::CreateAssistantResponse
Creates an Amazon Connect Wisdom assistant.
86 |
# File 'sig/client.rbs', line 86
def create_assistant: (
|
#create_assistant_association(params = {}) ⇒ Types::CreateAssistantAssociationResponse
Creates an association between an Amazon Connect Wisdom assistant and another resource. Currently, the only supported association is with a knowledge base. An assistant can have only a single association.
103 |
# File 'sig/client.rbs', line 103
def create_assistant_association: (
|
#create_content(params = {}) ⇒ Types::CreateContentResponse
Creates Wisdom content. Before to calling this API, use StartContentUpload to upload an asset.
119 |
# File 'sig/client.rbs', line 119
def create_content: (
|
#create_knowledge_base(params = {}) ⇒ Types::CreateKnowledgeBaseResponse
Creates a knowledge base.
InvalidRequestException error.
For example, you're programmatically managing your external knowledge base, and you want to add or remove one of the fields that is being ingested from Salesforce. Do the following:
-
Call DeleteKnowledgeBase.
-
Call DeleteDataIntegration.
-
Call CreateDataIntegration to recreate the DataIntegration or a create different one.
-
Call CreateKnowledgeBase.
136 |
# File 'sig/client.rbs', line 136
def create_knowledge_base: (
|
#create_quick_response(params = {}) ⇒ Types::CreateQuickResponseResponse
Creates a Wisdom quick response.
162 |
# File 'sig/client.rbs', line 162
def create_quick_response: (
|
#create_session(params = {}) ⇒ Types::CreateSessionResponse
Creates a session. A session is a contextual container used for generating recommendations. Amazon Connect creates a new Wisdom session for each contact on which Wisdom is enabled.
188 |
# File 'sig/client.rbs', line 188
def create_session: (
|
#delete_assistant(params = {}) ⇒ Struct
Deletes an assistant.
201 |
# File 'sig/client.rbs', line 201
def delete_assistant: (
|
#delete_assistant_association(params = {}) ⇒ Struct
Deletes an assistant association.
210 |
# File 'sig/client.rbs', line 210
def delete_assistant_association: (
|
#delete_content(params = {}) ⇒ Struct
Deletes the content.
220 |
# File 'sig/client.rbs', line 220
def delete_content: (
|
#delete_import_job(params = {}) ⇒ Struct
Deletes the quick response import job.
230 |
# File 'sig/client.rbs', line 230
def delete_import_job: (
|
#delete_knowledge_base(params = {}) ⇒ Struct
Deletes the knowledge base.
240 |
# File 'sig/client.rbs', line 240
def delete_knowledge_base: (
|
#delete_quick_response(params = {}) ⇒ Struct
Deletes a quick response.
249 |
# File 'sig/client.rbs', line 249
def delete_quick_response: (
|
#get_assistant(params = {}) ⇒ Types::GetAssistantResponse
Retrieves information about an assistant.
260 |
# File 'sig/client.rbs', line 260
def get_assistant: (
|
#get_assistant_association(params = {}) ⇒ Types::GetAssistantAssociationResponse
Retrieves information about an assistant association.
270 |
# File 'sig/client.rbs', line 270
def get_assistant_association: (
|
#get_content(params = {}) ⇒ Types::GetContentResponse
Retrieves content, including a pre-signed URL to download the content.
281 |
# File 'sig/client.rbs', line 281
def get_content: (
|
#get_content_summary(params = {}) ⇒ Types::GetContentSummaryResponse
Retrieves summary information about the content.
292 |
# File 'sig/client.rbs', line 292
def get_content_summary: (
|
#get_import_job(params = {}) ⇒ Types::GetImportJobResponse
Retrieves the started import job.
303 |
# File 'sig/client.rbs', line 303
def get_import_job: (
|
#get_knowledge_base(params = {}) ⇒ Types::GetKnowledgeBaseResponse
Retrieves information about the knowledge base.
314 |
# File 'sig/client.rbs', line 314
def get_knowledge_base: (
|
#get_quick_response(params = {}) ⇒ Types::GetQuickResponseResponse
Retrieves the quick response.
324 |
# File 'sig/client.rbs', line 324
def get_quick_response: (
|
#get_recommendations(params = {}) ⇒ Types::GetRecommendationsResponse
Retrieves recommendations for the specified session. To avoid
retrieving the same recommendations in subsequent calls, use
NotifyRecommendationsReceived. This API supports long-polling
behavior with the waitTimeSeconds parameter. Short poll is the
default behavior and only returns recommendations already available.
To perform a manual query against an assistant, use
QueryAssistant.
336 |
# File 'sig/client.rbs', line 336
def get_recommendations: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Retrieves information for a specified session.
349 |
# File 'sig/client.rbs', line 349
def get_session: (
|
#list_assistant_associations(params = {}) ⇒ Types::ListAssistantAssociationsResponse
Lists information about assistant associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
361 |
# File 'sig/client.rbs', line 361
def list_assistant_associations: (
|
#list_assistants(params = {}) ⇒ Types::ListAssistantsResponse
Lists information about assistants.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
374 |
# File 'sig/client.rbs', line 374
def list_assistants: (
|
#list_contents(params = {}) ⇒ Types::ListContentsResponse
Lists the content.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
386 |
# File 'sig/client.rbs', line 386
def list_contents: (
|
#list_import_jobs(params = {}) ⇒ Types::ListImportJobsResponse
Lists information about import jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
399 |
# File 'sig/client.rbs', line 399
def list_import_jobs: (
|
#list_knowledge_bases(params = {}) ⇒ Types::ListKnowledgeBasesResponse
Lists the knowledge bases.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
412 |
# File 'sig/client.rbs', line 412
def list_knowledge_bases: (
|
#list_quick_responses(params = {}) ⇒ Types::ListQuickResponsesResponse
Lists information about quick response.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
424 |
# File 'sig/client.rbs', line 424
def list_quick_responses: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
436 |
# File 'sig/client.rbs', line 436
def list_tags_for_resource: (
|
#notify_recommendations_received(params = {}) ⇒ Types::NotifyRecommendationsReceivedResponse
Removes the specified recommendations from the specified assistant's
queue of newly available recommendations. You can use this API in
conjunction with GetRecommendations and a waitTimeSeconds input
for long-polling behavior and avoiding duplicate recommendations.
447 |
# File 'sig/client.rbs', line 447
def notify_recommendations_received: (
|
#query_assistant(params = {}) ⇒ Types::QueryAssistantResponse
Performs a manual search against the specified assistant. To retrieve recommendations for an assistant, use GetRecommendations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
460 |
# File 'sig/client.rbs', line 460
def query_assistant: (
|
#remove_knowledge_base_template_uri(params = {}) ⇒ Struct
Removes a URI template from a knowledge base.
472 |
# File 'sig/client.rbs', line 472
def remove_knowledge_base_template_uri: (
|
#search_content(params = {}) ⇒ Types::SearchContentResponse
Searches for content in a specified knowledge base. Can be used to get a specific content resource by its name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
483 |
# File 'sig/client.rbs', line 483
def search_content: (
|
#search_quick_responses(params = {}) ⇒ Types::SearchQuickResponsesResponse
Searches existing Wisdom quick responses in a Wisdom knowledge base.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
505 |
# File 'sig/client.rbs', line 505
def search_quick_responses: (
|
#search_sessions(params = {}) ⇒ Types::SearchSessionsResponse
Searches for sessions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
542 |
# File 'sig/client.rbs', line 542
def search_sessions: (
|
#start_content_upload(params = {}) ⇒ Types::StartContentUploadResponse
Get a URL to upload content to a knowledge base. To upload content, first make a PUT request to the returned URL with your file, making sure to include the required headers. Then use CreateContent to finalize the content creation process or UpdateContent to modify an existing resource. You can only upload content to a knowledge base of type CUSTOM.
566 |
# File 'sig/client.rbs', line 566
def start_content_upload: (
|
#start_import_job(params = {}) ⇒ Types::StartImportJobResponse
Start an asynchronous job to import Wisdom resources from an uploaded source file. Before calling this API, use StartContentUpload to upload an asset that contains the resource data.
- For importing Wisdom quick responses, you need to upload a csv file including the quick responses. For information about how to format the csv file for importing quick responses, see Import quick responses.
^
578 |
# File 'sig/client.rbs', line 578
def start_import_job: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
599 |
# File 'sig/client.rbs', line 599
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
609 |
# File 'sig/client.rbs', line 609
def untag_resource: (
|
#update_content(params = {}) ⇒ Types::UpdateContentResponse
Updates information about the content.
620 |
# File 'sig/client.rbs', line 620
def update_content: (
|
#update_knowledge_base_template_uri(params = {}) ⇒ Types::UpdateKnowledgeBaseTemplateUriResponse
Updates the template URI of a knowledge base. This is only supported
for knowledge bases of type EXTERNAL. Include a single variable in
${variable} format; this interpolated by Wisdom using ingested
content. For example, if you ingest a Salesforce article, it has an
Id value, and you can set the template URI to
https://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view.
637 |
# File 'sig/client.rbs', line 637
def update_knowledge_base_template_uri: (
|
#update_quick_response(params = {}) ⇒ Types::UpdateQuickResponseResponse
Updates an existing Wisdom quick response.
648 |
# File 'sig/client.rbs', line 648
def update_quick_response: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2927 2928 2929 |
# File 'lib/aws-sdk-connectwisdomservice/client.rb', line 2927 def waiter_names [] end |