Class: Aws::ConnectWisdomService::Types::ContentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectwisdomservice/types.rb

Overview

Summary information about the content.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_arn ⇒ String

The Amazon Resource Name (ARN) of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#content_id ⇒ String

The identifier of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#content_type ⇒ String

The media type of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_arn ⇒ String

The Amazon Resource Name (ARN) of the knowledge base.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_id ⇒ String

The identifier of the knowledge base. This should not be a QUICK_RESPONSES type knowledge base if you're storing Wisdom Content resource to it.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#metadata ⇒ Hash<String,String>

A key/value map to store attributes without affecting tagging or recommendations. For example, when synchronizing data between an external system and Wisdom, you can store an external version identifier as metadata to utilize for determining drift.

Returns:

  • (Hash<String,String>)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#revision_id ⇒ String

The identifier of the revision of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#title ⇒ String

The title of the content.

Returns:

  • (String)


621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 621

class ContentSummary < Struct.new(
  :content_arn,
  :content_id,
  :content_type,
  :knowledge_base_arn,
  :knowledge_base_id,
  :metadata,
  :name,
  :revision_id,
  :status,
  :tags,
  :title)
  SENSITIVE = []
  include Aws::Structure
end