Class: Aws::ConnectWisdomService::Types::QuickResponseData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectwisdomservice/types.rb

Overview

Information about the quick response.

Constant Summary collapse

SENSITIVE =
[:channels]

Instance Attribute Summary collapse

Instance Attribute Details

#channels ⇒ Array<String>

The Amazon Connect contact channels this quick response applies to. The supported contact channel types include Chat.

Returns:

  • (Array<String>)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#content_type ⇒ String

The media type of the quick response content.

  • Use application/x.quickresponse;format=plain for quick response written in plain text.

  • Use application/x.quickresponse;format=markdown for quick response written in richtext.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#contents ⇒ Types::QuickResponseContents

The contents of the quick response.



2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#created_time ⇒ Time

The timestamp when the quick response was created.

Returns:

  • (Time)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#description ⇒ String

The description of the quick response.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#grouping_configuration ⇒ Types::GroupingConfiguration

The configuration information of the user groups that the quick response is accessible to.



2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#is_active ⇒ Boolean

Whether the quick response is active.

Returns:

  • (Boolean)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#knowledge_base_arn ⇒ String

The Amazon Resource Name (ARN) of the knowledge base.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#knowledge_base_id ⇒ String

The identifier of the knowledge base. This should not be a QUICK_RESPONSES type knowledge base if you're storing Wisdom Content resource to it. Can be either the ID or the ARN. URLs cannot contain the ARN.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#language ⇒ String

The language code value for the language in which the quick response is written.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#last_modified_by ⇒ String

The Amazon Resource Name (ARN) of the user who last updated the quick response data.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#last_modified_time ⇒ Time

The timestamp when the quick response data was last modified.

Returns:

  • (Time)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#name ⇒ String

The name of the quick response.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#quick_response_arn ⇒ String

The Amazon Resource Name (ARN) of the quick response.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#quick_response_id ⇒ String

The identifier of the quick response.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#shortcut_key ⇒ String

The shortcut key of the quick response. The value should be unique across the knowledge base.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#status ⇒ String

The status of the quick response data.

Returns:

  • (String)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/aws-sdk-connectwisdomservice/types.rb', line 2547

class QuickResponseData < Struct.new(
  :channels,
  :content_type,
  :contents,
  :created_time,
  :description,
  :grouping_configuration,
  :is_active,
  :knowledge_base_arn,
  :knowledge_base_id,
  :language,
  :last_modified_by,
  :last_modified_time,
  :name,
  :quick_response_arn,
  :quick_response_id,
  :shortcut_key,
  :status,
  :tags)
  SENSITIVE = [:channels]
  include Aws::Structure
end